Learn R Programming

stemmatology (version 0.3.2)

PCC.elimination: PCC Exploratory Methods: Elimination of Over-Conflicting Variant Locations

Description

This function removes from the database the variant locations labelled as over-conflicting by the PCC.overconflicting function.

Usage

PCC.elimination(x)

Arguments

x

an object of class pccOverconflicting.

Value

A numeric matrix, with witnesses in columns, variant locations in rows, and readings coded by a number, from which over-conflicting variant locations have been removed.

Details

When PCC.overconflicting has been applied to a PCC.conflicts object, it returns a table where over-conflicting variants are labeled as such. The PCC.elimination function simply removes those variants.

References

Camps, Jean-Baptiste, and Florian Cafiero. <U+2018>Stemmatology: An R Package for the Computer-Assisted Analysis of Textual Traditions<U+2019>. Proceedings of the Second Workshop on Corpus-Based Research in the Humanities (CRH-2), edited by Andrew U. Frank et al., 2018, pp. 65<U+2013>74, https://halshs.archives-ouvertes.fr/hal-01695903v1.

Camps, Jean-Baptiste, and Florian Cafiero. <U+2018>Genealogical Variant Locations and Simplified Stemma: A Test Case<U+2019>. Analysis of Ancient and Medieval Texts and Manuscripts: Digital Approaches, edited by Tara Andrews and Caroline Mac<U+00E9>, Brepols, 2015, pp. 69<U+2013>93, https://halshs.archives-ouvertes.fr/halshs-01435633, DOI: 10.1484/M.LECTIO-EB.5.102565.

See Also

PCC.Exploratory, PCC.conflicts, PCC.overconflicting, PCC.contam.

Examples

Run this code
# NOT RUN {
# Load data
data("fournival")
# Analyse its conflicts
myConflicts = PCC.conflicts(fournival)
# }
# NOT RUN {
# Interactive mode: identify over-conflicting VL
PCC.overconflicting(myConflicts)
# }
# NOT RUN {
# Non interactive mode
myConflicts = PCC.overconflicting(myConflicts, ask = FALSE, threshold = 0.06)
# Create a new DB without problematic VL
myNewDB = PCC.elimination(myConflicts)
# }

Run the code above in your browser using DataLab