Learn R Programming

stemmatology (version 0.3.2)

PCC.overconflicting: PCC Exploratory Methods: Identification of Over-Conflicting Variant Locations

Description

Given a network of conflicts (contradictions) between variant locations, this function helps in assessing which are the problematic ones.

Usage

PCC.overconflicting(x, ask = TRUE, threshold = NULL)

Arguments

x

an object of class pccConflicts.

ask

logical; if FALSE, decisions will be made without asking the user for input. Default: TRUE

threshold

numeric; the centrality threshold above which variant locations are considered to be over-conflicting. Used only with ask = FALSE.

Value

An object of class "pccOverconflicting", a list containing the three same first objects as the "pccConflicts" input,

edgelist

a two-column character matrix, giving the edges between variant locations in the network of conflicts

conflictsTotal

a one-column numeric matrix, giving the total number of conflicts per variant location

database

the original database used for the calculations

and adding
vertexAttributes

a two column character matrix, with a row per vertex of the network (i.e. variant location), giving its label and colour

Details

This function is dedicated to the identification of problematic variant locations, as defined in Poole 1974 and Camps & Cafiero 2015. It helps the user defining a threshold, defined in terms of centrality index, above which variant locations are considered to be over-conflicting. This output can be then passed to the function PCC.elimination, to remove them from the database.

References

Camps, Jean-Baptiste, and Florian Cafiero. <U+2018>Stemmatology: An R Package for the Computer-Assisted Analysis of Textual Traditions<U+2019>. Proceedings of the Second Workshop on Corpus-Based Research in the Humanities (CRH-2), edited by Andrew U. Frank et al., 2018, pp. 65<U+2013>74, https://halshs.archives-ouvertes.fr/hal-01695903v1.

Camps, Jean-Baptiste, and Florian Cafiero. <U+2018>Genealogical Variant Locations and Simplified Stemma: A Test Case<U+2019>. Analysis of Ancient and Medieval Texts and Manuscripts: Digital Approaches, edited by Tara Andrews and Caroline Mac<U+00E9>, Brepols, 2015, pp. 69<U+2013>93, https://halshs.archives-ouvertes.fr/halshs-01435633, DOI: 10.1484/M.LECTIO-EB.5.102565.

Poole, Eric. <U+2018>L<U+2019>analyse stemmatique des textes documentaires<U+2019>. La pratique des ordinateurs dans la critique des textes, Paris, 1979, p. 151-161.

Poole, Eric, <U+2018>The Computer in Determining Stemmatic Relationships<U+2019>. Computers and the Humanities, 8-4 (1974), p. 207-16.

See Also

PCC.Exploratory, PCC.conflicts, PCC.elimination.

Examples

Run this code
# NOT RUN {
# Load data
data("fournival")
# }
# NOT RUN {
# Analyse its conflicts
myConflicts = PCC.conflicts(fournival)
# }
# NOT RUN {
# Interactive mode: identify over-conflicting VL
PCC.overconflicting(myConflicts)
# }
# NOT RUN {
# Non interactive mode
PCC.overconflicting(myConflicts, ask = FALSE, threshold = 0.06)
# }

Run the code above in your browser using DataLab