Learn R Programming

stemmatology (version 0.3.2)

notreBesoin: Notre Besoin data set

Description

Data from the artificial tradition Notre-Besoin

Usage

data(notreBesoin)

Arguments

Format

A matrix with 42 observations on the following 13 variables.

nb1

a numeric vector

nb2

a numeric vector

nb3

a numeric vector

nb4

a numeric vector

nb5

a numeric vector

nb6

a numeric vector

nb7

a numeric vector

nb8

a numeric vector

nb9

a numeric vector

nb10

a numeric vector

nb11

a numeric vector

nb12

a numeric vector

nb13

a numeric vector

Details

The data comes from an artificial tradition, created under controlled circumstances. The variant locations have been selected to retain only substantial readings. The data is presented here as used in Camps & Cafiero 2015, without further modifications or corrections. Readings have been converted to numeric codes (0 being omission, and NA an absence of value).

References

Camps, Jean-Baptiste, and Florian Cafiero. <U+2018>Genealogical Variant Locations and Simplified Stemma: A Test Case<U+2019>. Analysis of Ancient and Medieval Texts and Manuscripts: Digital Approaches, edited by Tara Andrews and Caroline Mac<U+00E9>, Brepols, 2015, pp. 69<U+2013>93, https://halshs.archives-ouvertes.fr/halshs-01435633, DOI: 10.1484/M.LECTIO-EB.5.102565.

Examples

Run this code
# NOT RUN {
data(notreBesoin)
# }

Run the code above in your browser using DataLab